@@ -1,5 +1,7 @@
 """Custom form fields."""
 
+import six
+
 from django import forms
 
 from .version import Version
@@ -7,7 +9,7 @@ from .constants import DEFAULT_NUMBER_BITS
 from .utils import convert_version_int_to_string
 
 
-class VersionField(forms.IntegerField):
+class VersionField(forms.CharField):
 
     """A form field dedicated to version numbers."""
 
@@ -16,13 +18,11 @@ class VersionField(forms.IntegerField):
         return super(VersionField, self).__init__(**kwargs)
 
     def to_python(self, value):
-        """
-        Verifies that value can be converted to a Version object
-        """
+        """Verifies that value can be converted to a Version object."""
         if not value:
             return None
 
-        if isinstance(value, basestring):
+        if isinstance(value, six.string_types):
             return Version(value, self.number_bits)
 
         return Version(
